==> mysql-workbench-gpl-5.2.31-src.zip: mysql-workbench-gpl-5.2.31-src/library/grt/src/diff/changeobjects.h <==
/* 
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef __changeobjects_H
#define __changeobjects_H

#include <iostream>
#include <assert.h>
#include "diffchange.h"
#include "grtpp_util.h"

namespace grt 
{


//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC ObjectAttrModifiedChange : public DiffChange
{
  std::string _attr;
  DiffChange* subchange;
public:
  ObjectAttrModifiedChange(const std::string& attr, DiffChange* change) : DiffChange(ObjectAttrModified), _attr(attr), subchange(change) {}
  ~ObjectAttrModifiedChange() { delete subchange; }

  const std::string& get_attr_name() const { return _attr; }
  const DiffChange* get_subchange() const { return subchange; }

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << _attr << std::endl;
    subchange->dump_log(level+1);
  }
};

//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC ValueAddedChange : public DiffChange
{
  ValueRef _v;
public:
  const ValueRef get_value()const{return _v;};
  ValueAddedChange(ChangeType type, ValueRef v) : DiffChange(type), _v(copy_value(v, true)) {}
};

//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC ValueRemovedChange : public DiffChange
{
public:
  ValueRemovedChange() : DiffChange(ValueRemoved) {}
};

class MYSQLGRT_PUBLIC DictItemModifiedChange : public DiffChange
{
  std::string key;
  DiffChange* subchange;
public:
  DictItemModifiedChange(const std::string& i, DiffChange* change) : DiffChange(DictItemModified), key(i), subchange(change) {}
  ~DictItemModifiedChange() { delete subchange; }

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << key <<  std::endl;
    subchange->dump_log(level+1);
  }
};


//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC DictItemAddedChange : public DiffChange
{
  ValueRef _v;
  std::string key;
public:
  DictItemAddedChange(const std::string& i, ValueRef v) : DiffChange(DictItemAdded), _v(copy_value(v, true)), key(i) {}

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << key <<  std::endl;
  }
};


//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC DictItemRemovedChange : public DiffChange
{
  std::string key;
public:
  DictItemRemovedChange(const std::string& i) : DiffChange(DictItemRemoved), key(i) {}

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << key <<  std::endl;
  }
};

//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC SimpleValueChange : public DiffChange
{
  ValueRef _old;
  ValueRef _v;
public:


  SimpleValueChange(ValueRef old, ValueRef v) 
    : DiffChange(SimpleValue), _old(copy_value(old, false)), _v(copy_value(v, false)) 
  {}

  ValueRef get_new_value() const { return _v; }
  ValueRef get_old_value() const { return _old; }

  virtual void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name();
    std::cout << " new:" << _v.repr();
    std::cout << " old:" << _old.repr();
    std::cout << std::endl;
  }
};


//////////////////////////////////////////////////////////////

}
#endif

==> mysql-workbench-gpl-5.2.46-src.zip: mysql-workbench-gpl-5.2.46-src/library/grt/src/diff/changeobjects.h <==
/* 
 * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef __changeobjects_H
#define __changeobjects_H

#include <iostream>
#include <assert.h>
#include "diffchange.h"
#include "grtpp_util.h"

namespace grt 
{


//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC ObjectAttrModifiedChange : public DiffChange
{
  std::string _attr;
  boost::shared_ptr<DiffChange> subchange;
public:
  ObjectAttrModifiedChange(const std::string& attr, boost::shared_ptr<DiffChange> change) : DiffChange(ObjectAttrModified), _attr(attr), subchange(change) {subchange->set_parent(this);}

  const std::string& get_attr_name() const { return _attr; }
  const boost::shared_ptr<DiffChange> get_subchange() const { return subchange; }

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << _attr << std::endl;
    subchange->dump_log(level+1);
  }
};

//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC ValueAddedChange : public DiffChange
{
  ValueRef _v;
public:
  const ValueRef get_value()const{return _v;};
  ValueAddedChange(ChangeType type, ValueRef v) : DiffChange(type), _v(copy_value(v, true)) {}
};

//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC ValueRemovedChange : public DiffChange
{
public:
  ValueRemovedChange() : DiffChange(ValueRemoved) {}
};

class MYSQLGRT_PUBLIC DictItemModifiedChange : public DiffChange
{
  std::string key;
  boost::shared_ptr<DiffChange> subchange;
public:
  DictItemModifiedChange(const std::string& i, boost::shared_ptr<DiffChange> change) : DiffChange(DictItemModified), key(i), subchange(change) {subchange->set_parent(this);}

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << key <<  std::endl;
    subchange->dump_log(level+1);
  }
};


//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC DictItemAddedChange : public DiffChange
{
  ValueRef _v;
  std::string key;
public:
  DictItemAddedChange(const std::string& i, ValueRef v) : DiffChange(DictItemAdded), _v(copy_value(v, true)), key(i) {}

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << key <<  std::endl;
  }
};


//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC DictItemRemovedChange : public DiffChange
{
  std::string key;
public:
  DictItemRemovedChange(const std::string& i) : DiffChange(DictItemRemoved), key(i) {}

  void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name() << "::" << key << std::endl;
  }
};

//////////////////////////////////////////////////////////////
class MYSQLGRT_PUBLIC SimpleValueChange : public DiffChange
{
  ValueRef _old;
  ValueRef _v;
public:


  SimpleValueChange(ValueRef old, ValueRef v) 
    : DiffChange(SimpleValue), _old(old), _v(v) 
  {}

  ValueRef get_new_value() const { return _v; }
  ValueRef get_old_value() const { return _old; }

  virtual void dump_log(int level) const
  {
    std::cout << std::string(level, ' ');
    std::cout << get_type_name();
    std::cout << " new:" << _v.repr();
    std::cout << " old:" << _old.repr()<< std::endl;
  }
};


//////////////////////////////////////////////////////////////

}
#endif
